@@ -13,9 +13,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Written by:
  *     Jasper St. Pierre <jstpierre@mecheye.net>
@@ -38,11 +36,6 @@ G_BEGIN_DECLS
 typedef struct _GisAssistant        GisAssistant;
 typedef struct _GisAssistantClass   GisAssistantClass;
 
-typedef enum {
-  GIS_ASSISTANT_PREV,
-  GIS_ASSISTANT_NEXT,
-} GisAssistantDirection;
-
 struct _GisAssistant
 {
   GtkBox parent;
@@ -51,8 +44,6 @@ struct _GisAssistant
 struct _GisAssistantClass
 {
   GtkBoxClass parent_class;
-
-  void (* next_page) (GisAssistant *assistant, GisPage *page);
 };
 
 GType gis_assistant_get_type (void);
