@@ -31,6 +31,7 @@ enum {
   PROP_TITLE,
   PROP_SUBTITLE,
   PROP_ICON_NAME,
+  PROP_PIXBUF,
   PROP_SHOW_ICON,
   PROP_LAST,
 };
@@ -80,7 +81,6 @@ gis_page_header_get_property (GObject    *object,
                               GParamSpec *pspec)
 {
   GisPageHeader *header = GIS_PAGE_HEADER (object);
-  gchar *icon_name = NULL;
 
   switch (prop_id)
     {
@@ -93,8 +93,11 @@ gis_page_header_get_property (GObject    *object,
       break;
 
     case PROP_ICON_NAME:
-      g_object_get (header->icon, "icon-name", &icon_name, NULL);
-      g_value_take_string (value, icon_name);
+      g_object_get_property (G_OBJECT (header->icon), "icon-name", value);
+      break;
+
+    case PROP_PIXBUF:
+      g_object_get_property (G_OBJECT (header->icon), "pixbuf", value);
       break;
 
     case PROP_SHOW_ICON:
@@ -128,7 +131,11 @@ gis_page_header_set_property (GObject      *object,
       break;
 
     case PROP_ICON_NAME:
-      g_object_set (header->icon, "icon-name", g_value_get_string (value), NULL);
+      g_object_set_property (G_OBJECT (header->icon), "icon-name", value);
+      break;
+
+    case PROP_PIXBUF:
+      g_object_set_property (G_OBJECT (header->icon), "pixbuf", value);
       break;
 
     case PROP_SHOW_ICON:
@@ -174,6 +181,12 @@ gis_page_header_class_init (GisPageHeaderClass *klass)
                          NULL,
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
+  obj_props[PROP_PIXBUF] =
+    g_param_spec_object ("pixbuf",
+                         "", "",
+                         GDK_TYPE_PIXBUF,
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
   obj_props[PROP_SHOW_ICON] =
     g_param_spec_boolean ("show-icon",
                           "", "",
