@@ -417,9 +417,11 @@ get_locale_infos (CcInputChooser *chooser)
 	add_rows_to_list (chooser, list, INPUT_SOURCE_TYPE_XKB, id);
 	g_list_free (list);
 
-	list = gnome_xkb_info_get_layouts_for_country (priv->xkb_info, country);
-	add_rows_to_list (chooser, list, INPUT_SOURCE_TYPE_XKB, id);
-	g_list_free (list);
+	if (country != NULL) {
+		list = gnome_xkb_info_get_layouts_for_country (priv->xkb_info, country);
+		add_rows_to_list (chooser, list, INPUT_SOURCE_TYPE_XKB, id);
+		g_list_free (list);
+	}
 
         choose_non_extras (chooser);
 
